/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007, 2008 Muneyuki Noguchi <nogu@users.sourceforge.jp>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "parametricoptionwidget.h"

#include <QtGui/QGridLayout>
#include <QtGui/QCheckBox>

#include "parametric.h"

ParametricOptionWidget::ParametricOptionWidget(QWidget *parent)
: AbstractOptionWidget(parent), parametric(0)
{
	setWindowTitle(tr("Parameter"));
}

ParametricOptionWidget::~ParametricOptionWidget()
{
	delete parametric;
}

void ParametricOptionWidget::construct()
{
	setWhatsThis("set parametric");

	parametricCheckBox = new QCheckBox;
	parametricCheckBox->setText(tr("&Parametric functions"));
	connect(parametricCheckBox, SIGNAL(toggled(bool)),
			this, SIGNAL(modified()));

	QGridLayout *mainLayout = new QGridLayout;
	mainLayout->addWidget(parametricCheckBox, 0, 0);
	mainLayout->addItem(new QSpacerItem(0, 0, 
				QSizePolicy::Expanding, QSizePolicy::Minimum), 0, 1);
	mainLayout->addItem(new QSpacerItem(0, 0,
				QSizePolicy::Minimum, QSizePolicy::Expanding), 1, 0);

	setLayout(mainLayout);
}

void ParametricOptionWidget::init()
{
	delete parametric;
	parametric = new Parametric;
	setWidget();
}

void ParametricOptionWidget::apply()
{
	parametric->setParametric(parametricCheckBox->isChecked());
	emit executed(parametric->command());
}

void ParametricOptionWidget::setWidget()
{
	parametricCheckBox->setChecked(parametric->isParametric());
}
